function PopQs = DEBIPMNotShrink_Macroorganism(E_Y,MatrixSize,Lb,Lp,Lm,Rm,rb,kappa,mu_juv,mu_ad)

% parameters for IPM
E_Ystdev=0.1; % sigma(Y)
Lmin = 0.7*Lb; % cm used to define limits of matrix approximation; 70% of Lb

[S, R, G, D, meshpts] = BigMatrixNotShrink(MatrixSize,Lmin,Lm,Lp,Rm,Lm,E_Y,E_Ystdev,rb,kappa,Lb,mu_juv,mu_ad);
kernelDEB = G*S + D*R; 
% calculate lambda, ssd, and rv
[W,d] = eig(kernelDEB); lambda1 = diag(d); imax = find(lambda1==max(lambda1)); 
 V=conj(inv(W)); lambda = lambda1(imax); % population growth rate
 w1=W(:,imax); v1 = real(V(imax,:))';
 ssd = w1/sum(w1); ssd = ssd'; % stable stage distribution
 lambda2 = max(lambda1(lambda1~=lambda)); % second eigen value
 dampingratio = lambda/(abs(lambda2)); % damping ratio p95 in Caswell (2001)

% calculation of mean lifetime reproductive succes R0 
% required to calculate generation time below
[m,p]=size(kernelDEB); TS = G*S; Fmat = D*R; 
R0mat = Fmat*inv((eye(m)-TS)); meanLRS = max(eig(R0mat)); 

% generation time using approximation
GT_approx = log(meanLRS)/log(lambda);

% calculate longevity
N = inv(eye(MatrixSize) - TS); % equation 4.20 in [Caswell, H. Sensitivity Analysis: Matrix Methods in Demography and Ecology. Demographic Research Monographs. Springer Open, p.51 (2019).]
life_expectancy_at_length = ones(1,MatrixSize)*N; % p51 in [Caswell, H. Sensitivity Analysis: Matrix Methods in Demography and Ecology. Demographic Research Monographs. Springer Open, p.51 (2019).]
index_juvenile_longevity = min(find(meshpts>Lb)); 
index_adult_longevity = min(find(meshpts>Lp));
L_alpha = life_expectancy_at_length(index_juvenile_longevity); % age at maturity
L_omega = life_expectancy_at_length(index_adult_longevity); % mature life expectancy
longevity = round(L_alpha + L_omega); % used to calculate lx mx schedules

% return lx mx schedules (Caswell 2001, p. 118-121)
[lx, mx] = LifeHistory(S, R, G, D, longevity);
[lxmxres, lxmx, lxres, mxres] = OffspringDist(lx, mx);

% Net reproductive rate calculated from lx mx schedules
% This should be very similar to R0
% (Salguero-Gomez 2017, Appendix Table S1)
NetReprRate = sum(ssd.*sum(lxmxres,1)); 

% Survivorship curve H calculated from lx schedule
% (Keyfitz 1997, Keyfitz & Caswell 2005); see equation in de Vries et al (2022)
% first remove lx schedules that only contain 1 in the first row and zeros elsewhere
lxres_pos = NaN(size(lxres)); [q,r] = size(lxres_pos); indexpos = all(lxres); 
indexpos=repmat(indexpos,q,1); lxres_pos(indexpos) = lxres(indexpos); 
% then calculate survivorcurve H:
SurvivorCurve = -sum(ssd.*sum(log(lxres_pos).*lxres_pos,'omitnan'),'omitnan')./sum(ssd.*sum(lxres_pos,'omitnan'),'omitnan'); 
        
% Degree of iteroparity
% Caswell (2019): the variance in the age at reproduction is a useful measure of the extent of iteroparity. 
% [Caswell, H. Sensitivity Analysis: Matrix Methods in Demography and Ecology. Demographic Research Monographs. Springer Open, p.51 (2019).]
% first calculate mean size at reproduction following equation 10.82 in [Caswell, H. Sensitivity Analysis: Matrix Methods in Demography and Ecology. Demographic Research Monographs. Springer Open, p.51 (2019).]
VecOnesT=ones(1,MatrixSize);
SizeSpecificFertilityDistribution = sum(mxres); 
% transpose vector for MeanSizeAtRepro calculation below
SizeSpecificFertilityDistribution=SizeSpecificFertilityDistribution';
% calculate mean size at reproduction (Caswell 2019, equation 10.82) (note matrix multiplication)
MeanSizeAtRepro = meshpts*SizeSpecificFertilityDistribution/(VecOnesT*SizeSpecificFertilityDistribution);
% then calculate variance in the age of reproduction 
% calculate in steps using equation 10.82, 10.86 and 10.87 in [Caswell, H. Sensitivity Analysis: Matrix Methods in Demography and Ecology. Demographic Research Monographs. Springer Open, p.51 (2019).]
c=meshpts'; temp1 = c.*c; temp1T=temp1';
term1 = (temp1T*SizeSpecificFertilityDistribution)/(VecOnesT*SizeSpecificFertilityDistribution); % equation 10.87
term2 = MeanSizeAtRepro.^2; % equation 10.82
Vf = term1 - term2; % variance in the age of reproduction, equation 10.86
SDSizeAtRepro = sqrt(Vf); % standard deviation of the age of reproduction
% calculate coefficient of variation to compare different size-specific fertility distributions
CoefVar = SDSizeAtRepro / MeanSizeAtRepro;
% take coefficient of variation to inform on degree of iteroparity
% variance will be zero in case of semelparity, but higher for iteroparous species     
DegreeItero = CoefVar;    

% mean sexual reproduction phi (mean number of recruits, SSD
% weighted) (Salguero-Gomez 2017, Appendix Table S1); defined
% as mean vital rate of sexual reproduction in Salguero-Gomez
% et al. 2016
F = D*R; Phi = sum(sum(F).*ssd);

% progressive growth: mean of vital rates on lower triangle of G matrix (below the antidiagonal)
% replace zeros with NaN so they are excluded from calculating means
LowerTriangle = tril(G,-1); LowerTriangle(LowerTriangle==0)=NaN;
Proggrowth = mean(mean(ssd.*LowerTriangle,'omitnan'),'omitnan'); % ssd corrected overall mean

% retrogressive growth: mean of vital rates on upper triangle of G matrix (above the antidiagonal)
% replace zeros with NaN so they are excluded from calculating means
UpperTriangle = triu(G,1); UpperTriangle(UpperTriangle==0)=NaN;
Retrogrowth = mean(mean(ssd.*UpperTriangle,'omitnan'),'omitnan'); % ssd corrected overall mean

% store all values
PopQs = [E_Y, GT_approx, SurvivorCurve, L_alpha, Proggrowth,...
    Retrogrowth, Phi, DegreeItero, NetReprRate, L_omega, lambda, dampingratio];
        
        