% This is the script file where you input the DEB-IPM parameters and the feeding levels. It calls: :
% 1. DEBIPMNotShrink_Macroorganism to calculate the life history traits
% 2. DEBIPMNotShrink_sens to do the elasticity analysis

% make sure your working path is the folder that contains all files extracted from Figshare

warning('off')
%%
%%% THIS IS WHERE YOU SET YOUR PARAMETER VALUES

% set minimum and maximum feeding levels
E_Ymin = 0.5; % minimum feeding level; suggestion: 0.5
E_Ymax = 1; % maximum feeding level; suggestion: 1
step = 50; %step size between E_Ymin and E_Ymax: suggestion: 50

% DEB parameters (this is an example of the reef manta ray Mobula alfredi)
Lb = 140; % length at birth in cm
Lp = 390; % length at puberty in cm
Lm = 550; % maximum length in cm 
kappa = 0.80; % fraction energy allocation to respiration (as opposed to reproduction)
mu_juv = 0.035; % juvenile mortality rate (per year)
mu_ad = 0.066; % adult mortality rate (per year)
rb = 0.07; % von Bertalanffy growth rate (per year)
Rm = 0.13; % maximum number of offspring produced per year at L_m

%% %%%%%%% NO NEED TO CHANGE CODE BELOW HERE %%%%%%%%%%%%%%%%%%%%%

% set MatrixSize
MatrixSize = 200; % number of size bins of matrix approximation of DEBIPM. suggestion: 200

%Calculate life history traits and run elasticity analysis for each value of E_Y

% set feeding level range
E_Y=linspace(E_Ymin,E_Ymax,step); % Feeding level range

% calculate generation time, survivorship curve, age at sexual maturity, 
% progressive growth, retrogressive growth, mean sexual reproduction, degree of iteroparity, 
% net reproductive rate, mature life expectancy, population growth rate and demographic resilience (damping ratio)
    for n=1:length(E_Y); n/length(E_Y)                       
    PopQstemp = DEBIPMNotShrink_Macroorganism(E_Y(n),MatrixSize,Lb,Lp,Lm,Rm,rb,kappa,mu_juv,mu_ad);
    LHtraits(n,:) = PopQstemp;     % store all values
    
    % run elasticity analysis
    % parameters perturbed are in this order: Lb, Lp, Lm, Rm, rb, mu_adult, mu_juv
    % MostSensPar is an index value idenfitying which parameter is the most
    % influential to the population growth rate. For example, if MostSensPar
    % = 1, then Lb is the parameter that has the highest influence on lambda.
    % If MostSensPar = 7, then juvenile mortality rate has the highest influence on lambda.
    MostSensPartemp  = DEBIPMNotShrink_sens(E_Y(n),MatrixSize,Lp,rb,Rm,Lm,kappa,Lb,mu_juv,mu_ad);
    ElasPars(n,:) = MostSensPartemp;  % store all values
    end
  
% plot life history traits for all feeding levels
subplot(3,4,1); plot(E_Y,LHtraits(:,2),'k-','LineWidth',2);  axis square;  box off
ylabel('Generation time','FontSize',14); xlabel(' ');  
subplot(3,4,2); plot(E_Y,LHtraits(:,3),'k-','LineWidth',2);   axis square;  box off
ylabel('Survivorship curve','FontSize',14);  xlabel(' ');  set(gca,'FontSize',12); 
subplot(3,4,3); plot(E_Y,LHtraits(:,4),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Age at maturity','FontSize',14);  xlabel(' ');  set(gca,'FontSize',12); 
subplot(3,4,4); plot(E_Y,LHtraits(:,5),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Progressive growth','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,5); plot(E_Y,LHtraits(:,6),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Retrogressive growth','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,6); plot(E_Y,LHtraits(:,7),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Mean sexual reproduction','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,7); plot(E_Y,LHtraits(:,8),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Degree of iteroparity','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,8); plot(E_Y,LHtraits(:,9),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Net reproductive rate','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,9); plot(E_Y,LHtraits(:,10),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Mature life expectancy','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,10); plot(E_Y,LHtraits(:,11),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Population growth rate','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
subplot(3,4,11); plot(E_Y,LHtraits(:,12),'k-','LineWidth',2); axis square;  box off; hold on
ylabel('Demographic resilience','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);

figure

% plot elasticity results
plot(E_Y,ElasPars,'k*','LineWidth',2);  ylim([1 9]); axis square;  box off
ylabel('Parameter','FontSize',14);  xlabel('Feeding level');  set(gca,'FontSize',12);
txt = '1 = L_b, 2 = L_p, 3 = L_m, 4 = R_m,5 = r_B, 6 = mu_a, 7 = mu_j';
text(1.05*E_Ymin,8,txt)

%% save LHtraits

header = {'E_Y', 'GT_approx', 'SurvivorCurve', 'L_alpha', 'Proggrowth',...
    'Retrogrowth', 'Phi', 'DegreeItero', 'NetReprRate', 'L_omega', 'lambda', 'dampingratio'};
LHtraits = [header; num2cell(LHtraits)]; % add headers